@@ -25,8 +25,11 @@ import (
 	"io/ioutil"
 	"os"
 
+	"github.com/apache/skywalking-satellite/plugins/client/grpc/lb"
+
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/credentials"
+	"google.golang.org/grpc/credentials/insecure"
 	"google.golang.org/grpc/metadata"
 )
 
@@ -41,7 +44,7 @@ func (c *Client) loadConfig() (*[]grpc.DialOption, error) {
 		}
 		options = append(options, grpc.WithTransportCredentials(credentials.NewTLS(configTLS)))
 	} else {
-		options = append(options, grpc.WithInsecure())
+		options = append(options, grpc.WithTransportCredentials(insecure.NewCredentials()))
 	}
 
 	var authHeader metadata.MD
@@ -73,8 +76,8 @@ func (c *Client) loadConfig() (*[]grpc.DialOption, error) {
 		return err
 	})
 
-	// using round-robin load balancer
-	options = append(options, grpc.WithDefaultServiceConfig(`{"loadBalancingPolicy":"round_robin"}`))
+	// using self build load balancer
+	options = append(options, grpc.WithDefaultServiceConfig(fmt.Sprintf("{\"loadBalancingPolicy\":\"%s\"}", lb.Name)))
 
 	return &options, nil
 }
@@ -84,12 +87,6 @@ func (c *Client) configTLS() (tc *tls.Config, tlsErr error) {
 	if err := checkTLSFile(c.CaPemPath); err != nil {
 		return nil, err
 	}
-	if err := checkTLSFile(c.ClientKeyPath); err != nil {
-		return nil, err
-	}
-	if err := checkTLSFile(c.ClientPemPath); err != nil {
-		return nil, err
-	}
 	tlsConfig := new(tls.Config)
 	tlsConfig.Renegotiation = tls.RenegotiateNever
 	tlsConfig.InsecureSkipVerify = c.InsecureSkipVerify
@@ -98,14 +95,24 @@ func (c *Client) configTLS() (tc *tls.Config, tlsErr error) {
 		return nil, err
 	}
 	certPool := x509.NewCertPool()
-	certPool.AppendCertsFromPEM(caPem)
+	if !certPool.AppendCertsFromPEM(caPem) {
+		return nil, fmt.Errorf("failed to append certificates")
+	}
 	tlsConfig.RootCAs = certPool
 
-	clientPem, err := tls.LoadX509KeyPair(c.ClientPemPath, c.ClientKeyPath)
-	if err != nil {
-		return nil, err
+	if c.ClientKeyPath != "" && c.ClientPemPath != "" {
+		if err := checkTLSFile(c.ClientKeyPath); err != nil {
+			return nil, err
+		}
+		if err := checkTLSFile(c.ClientPemPath); err != nil {
+			return nil, err
+		}
+		clientPem, err := tls.LoadX509KeyPair(c.ClientPemPath, c.ClientKeyPath)
+		if err != nil {
+			return nil, err
+		}
+		tlsConfig.Certificates = []tls.Certificate{clientPem}
 	}
-	tlsConfig.Certificates = []tls.Certificate{clientPem}
 	return tlsConfig, nil
 }
 
